@@ -16,8 +16,9 @@ import ui.AnselA_Graphics as Graphics
 from PIL import Image
 from PIL import ImageDraw
 from PIL import ImageEnhance
+
+from PyQt4 import *
 from PyQt4 import QtGui
-from PyQt4 import QtCore 
 from PyQt4.QtGui import QMainWindow
 from PyQt4.QtCore import pyqtSignature
 from ui.Ui_mainWindow import Ui_MainWindow
@@ -43,7 +44,8 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.postSetup()
         self.ImageDisplayRefresh(True)
         self.ShowApply(False)
-    
+
+
     def postSetup(self):
         self.tabStrip.setCurrentIndex(0)
 
@@ -192,41 +194,39 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
                 #source[B].point(lambda i: i * 1.2)
                 im = source[B].convert("L")
             elif cSource == "C":
-                source[B].point(lambda i: i * 1.2)
-                source[G].point(lambda i: i * 1.2)
-                out = Image.merge("RGB", (N, source[G],  source[B]) )
+#                source[B].point(lambda i: i * 1.2)
+#                source[G].point(lambda i: i * 1.2)
+                out = Image.merge("RGB", (N, source[G],  source[B]))
                 im = out.convert("L")
             elif cSource == "BC":
-                out = Image.merge("RGB", (N, source[G],  source[B]) )
+                out = Image.merge("RGB", (source[B], source[G],  source[B]))
                 im = out.convert("L")
             elif cSource == "BM":
-                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .33)
-                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .66)
-                out = Image.merge("RGB", (source[R], N,  source[B]) )
+                out = Image.merge("RGB", (source[R], source[B],  source[B]))
                 im = out.convert("L")
             elif cSource == "M":
-                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .5)
-                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .5)
+#                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .5)
+#                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .5)
                 out = Image.merge("RGB", (source[R], N,  source[B])  )
                 im = out.convert("L")
             elif cSource == "RM":
-                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .33)
-                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .66)
-                out = Image.merge("RGB", (source[R], N,  source[B])  )
+#                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .33)
+#                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .66)
+                out = Image.merge("RGB", (source[R], source[R],  source[B]) )
                 im = out.convert("L")
             elif cSource == "RY":
-                out = Image.merge("RGB", (source[R], source[G],  N) )
+                out = Image.merge("RGB", (source[R], source[G],  source[R]) )
                 im = out.convert("L")
             elif cSource == "Y":
-                source[R].point(lambda i: i * 1.66)
-                source[G].point(lambda i: i * 1.66)
+#                source[R].point(lambda i: i * 1.66)
+#                source[G].point(lambda i: i * 1.66)
                 out = Image.merge("RGB", (source[R], source[G],  N) )
                 im = out.convert("L")
             elif cSource == "GY":
-                out = Image.merge("RGB", (source[R], source[G],  N) )
+                out = Image.merge("RGB", (source[R], source[G],  source[G]) )
                 im = out.convert("L")                
             elif cSource == "GC":
-                out = Image.merge("RGB", (N, source[G],  source[B]) )
+                out = Image.merge("RGB", (source[G], source[G],  source[B]) )
                 im = out.convert("L")    
             
             im = im.convert("RGB")
@@ -375,7 +375,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
                 
             im = imageToEdit
                 
-            if cSource =="Br":
+            if cSource =="Br": 
                 enhancer = ImageEnhance.Brightness(im)
                 Eim = enhancer.enhance(self.val.valBr*-1*0.001)
             if cSource =="Co":
